@@ -70,7 +70,8 @@ cppobj_additional = [
 			"CDC.cpp",
 			"Stream.cpp",
 			"IPAddress.cpp",
-			"USBCore.cpp"
+			"USBCore.cpp",
+			"HID.cpp"
 			]
 
 defc = [
@@ -207,6 +208,12 @@ def compile(tw, id, output, notify):
 		compline.extend(flags)
 		compline.extend(["-I" + os.path.join(i, "utility") for i in preproc.generateLibs(id, buf)])
 		compline.extend(misc.getArduinoIncludes())
+		compline.extend(["-I"+os.getcwd()])
+		try:
+			localDir = os.path.dirname(tw.get_data("file"))
+			compline.extend(["-I"+localDir])
+			compline.extend(["-I"+os.path.abspath(os.path.join(localDir, ".."))])
+		except: pass
 		compline.append(pre_file)
 		compline.append("-o"+pre_file+".o")
 		misc.printMessageLn(output, ' '.join(compline)+"\n")
@@ -298,6 +305,11 @@ def compileObjects(objects, flags, objout, output):
 		compline.append("-mmcu="+b.getBoardMCU(b.getBoard()))
 		compline.append("-DF_CPU="+b.getBoardFCPU(b.getBoard()))
 		compline.extend(misc.getArduinoIncludes())
+		if misc.getArduinoVersion() >= 100:
+			try:
+				compline.append("-DUSB_VID="+b.getBoardUSBVID(b.getBoard()))
+				compline.append("-DUSB_PID="+b.getBoardUSBPID(b.getBoard()))
+			except: pass
 		if misc.getArduinoVersion() >= 100:
 			compline.append("-DARDUINO=100")
 		compline.append(os.path.join(misc.getArduinoPath(), i))
@@ -321,14 +333,16 @@ def getLibraries():
 	#		fl = os.path.join(q, library, d)
 	#		if os.path.exists(fl):
 
-"""checks whether library exists (it has been compiled and tries to compile it otherwise"""
+"""checks whether library exists (if it has been compiled and tries to compile it otherwise"""
 """@returns a list of compiled objects"""
 def validateLib(library, tempobj, flags, output, notify):
 	"""compile library also try to compile every cpp under libdir"""
 	"""also try to compile utility dir if present"""
-	paths = ["", misc.getArduinoLibsPath()]
+	paths = ["", misc.getArduinoLibsPath(), misc.getLocalPath()]
 	if config.user_library != None and config.user_library != -1:
 		paths.extend(i.strip() for i in config.user_library.split(';'))
+	paths.append(os.path.dirname(config.sketchFile))
+	paths.append(os.path.abspath(os.path.join(os.path.dirname(config.sketchFile), "..")))
 	dirs = ["", "utility"]
 	b = board.Board()
 	res = []
